/*
 * Fabric3
 * Copyright (c) 2009-2011 Metaform Systems
 *
 * Fabric3 is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version, with the
 * following exception:
 *
 * Linking this software statically or dynamically with other
 * modules is making a combined work based on this software.
 * Thus, the terms and conditions of the GNU General Public
 * License cover the whole combination.
 *
 * As a special exception, the copyright holders of this software
 * give you permission to link this software with independent
 * modules to produce an executable, regardless of the license
 * terms of these independent modules, and to copy and distribute
 * the resulting executable under terms of your choice, provided
 * that you also meet, for each linked independent module, the
 * terms and conditions of the license of that module. An
 * independent module is a module which is not derived from or
 * based on this software. If you modify this software, you may
 * extend this exception to your version of the software, but
 * you are not obligated to do so. If you do not wish to do so,
 * delete this exception statement from your version.
 *
 * Fabric3 is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the
 * GNU General Public License along with Fabric3.
 * If not, see <http://www.gnu.org/licenses/>.
 *
 * ----------------------------------------------------
 *
 * Portions originally based on Apache Tuscany 2007
 * licensed under the Apache 2.0 license.
 *
 */
package org.fabric3.model.type.definitions;

import java.util.Set;
import javax.xml.namespace.QName;

/**
 * A policy type.
 *
 * @version $Rev: 9883 $ $Date: 2011-01-19 00:26:18 +0000 (Wed, 19 Jan 2011) $
 */
public class AbstractPolicyType extends AbstractPolicyDefinition {
    private static final long serialVersionUID = -2910491671004468756L;

    private final Set<QName> alwaysProvide;
    private final Set<QName> mayProvide;

    /**
     * @param name          Name of the binding type.
     * @param alwaysProvide Intents this binding always provide.
     * @param mayProvide    Intents this binding may provide.
     */
    public AbstractPolicyType(QName name, Set<QName> alwaysProvide, Set<QName> mayProvide) {
        super(name);
        this.alwaysProvide = alwaysProvide;
        this.mayProvide = mayProvide;
    }

    /**
     * @return Intents this binding always provide.
     */
    public Set<QName> getAlwaysProvide() {
        return alwaysProvide;
    }

    /**
     * @return Intents this binding may provide.
     */
    public Set<QName> getMayProvide() {
        return mayProvide;
    }


}
